@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -12,10 +11,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,9 +34,7 @@ enum
 
 
 
-static void               exo_die_command_model_class_init            (ExoDieCommandModelClass  *klass);
 static void               exo_die_command_model_tree_model_init       (GtkTreeModelIface        *iface);
-static void               exo_die_command_model_init                  (ExoDieCommandModel       *command_model);
 static void               exo_die_command_model_finalize              (GObject                  *object);
 static GtkTreeModelFlags  exo_die_command_model_get_flags             (GtkTreeModel             *tree_model);
 static gint               exo_die_command_model_get_n_columns         (GtkTreeModel             *tree_model);
@@ -93,45 +90,12 @@ struct _ExoDieCommandModel
 
 
 
-static GObjectClass *exo_die_command_model_parent_class;
-static guint         command_model_signals[LAST_SIGNAL];
+static guint command_model_signals[LAST_SIGNAL];
 
 
 
-GType
-exo_die_command_model_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (ExoDieCommandModelClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) exo_die_command_model_class_init,
-        NULL,
-        NULL,
-        sizeof (ExoDieCommandModel),
-        0,
-        (GInstanceInitFunc) exo_die_command_model_init,
-        NULL,
-      };
-
-      static const GInterfaceInfo tree_model_info =
-      {
-        (GInterfaceInitFunc) exo_die_command_model_tree_model_init,
-        NULL,
-        NULL,
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, I_("ExoDieCommandModel"), &info, 0);
-      g_type_add_interface_static (type, GTK_TYPE_TREE_MODEL, &tree_model_info);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_CODE (ExoDieCommandModel, exo_die_command_model, G_TYPE_OBJECT,
+    G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, exo_die_command_model_tree_model_init))
 
 
 
@@ -140,9 +104,6 @@ exo_die_command_model_class_init (ExoDieCommandModelClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_die_command_model_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_die_command_model_finalize;
 
@@ -278,17 +239,17 @@ exo_die_command_model_get_path (GtkTreeModel *tree_model,
                                 GtkTreeIter  *iter)
 {
   ExoDieCommandModel *command_model = EXO_DIE_COMMAND_MODEL (tree_model);
-  gint                index;
+  gint                idx;
 
   g_return_val_if_fail (EXO_DIE_IS_COMMAND_MODEL (command_model), NULL);
   g_return_val_if_fail (iter->stamp == command_model->stamp, NULL);
 
   /* determine the index of the iter */
-  index = g_slist_position (command_model->items, iter->user_data);
-  if (G_UNLIKELY (index < 0))
+  idx = g_slist_position (command_model->items, iter->user_data);
+  if (G_UNLIKELY (idx < 0))
     return NULL;
 
-  return gtk_tree_path_new_from_indices (index, -1);
+  return gtk_tree_path_new_from_indices (idx, -1);
 }
 
 
