@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -12,10 +11,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,9 +36,7 @@ typedef struct _ExoDieDesktopItem ExoDieDesktopItem;
 
 
 
-static void               exo_die_desktop_model_class_init            (ExoDieDesktopModelClass  *klass);
 static void               exo_die_desktop_model_tree_model_init       (GtkTreeModelIface        *iface);
-static void               exo_die_desktop_model_init                  (ExoDieDesktopModel       *desktop_model);
 static void               exo_die_desktop_model_finalize              (GObject                  *object);
 static GtkTreeModelFlags  exo_die_desktop_model_get_flags             (GtkTreeModel             *tree_model);
 static gint               exo_die_desktop_model_get_n_columns         (GtkTreeModel             *tree_model);
@@ -111,44 +108,8 @@ struct _ExoDieDesktopItem
 
 
 
-static GObjectClass *exo_die_desktop_model_parent_class;
-
-
-
-GType
-exo_die_desktop_model_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (ExoDieDesktopModelClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) exo_die_desktop_model_class_init,
-        NULL,
-        NULL,
-        sizeof (ExoDieDesktopModel),
-        0,
-        (GInstanceInitFunc) exo_die_desktop_model_init,
-        NULL,
-      };
-
-      static const GInterfaceInfo tree_model_info =
-      {
-        (GInterfaceInitFunc) exo_die_desktop_model_tree_model_init,
-        NULL,
-        NULL,
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, I_("ExoDieDesktopModel"), &info, 0);
-      g_type_add_interface_static (type, GTK_TYPE_TREE_MODEL, &tree_model_info);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_CODE (ExoDieDesktopModel, exo_die_desktop_model, G_TYPE_OBJECT,
+    G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, exo_die_desktop_model_tree_model_init))
 
 
 
@@ -157,9 +118,6 @@ exo_die_desktop_model_class_init (ExoDieDesktopModelClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_die_desktop_model_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_die_desktop_model_finalize;
 }
@@ -288,17 +246,17 @@ exo_die_desktop_model_get_path (GtkTreeModel *tree_model,
                                 GtkTreeIter  *iter)
 {
   ExoDieDesktopModel *desktop_model = EXO_DIE_DESKTOP_MODEL (tree_model);
-  gint                index;
+  gint                idx;
 
   g_return_val_if_fail (EXO_DIE_IS_DESKTOP_MODEL (desktop_model), NULL);
   g_return_val_if_fail (iter->stamp == desktop_model->stamp, NULL);
 
   /* determine the index of the iter */
-  index = g_slist_position (desktop_model->items, iter->user_data);
-  if (G_UNLIKELY (index < 0))
+  idx = g_slist_position (desktop_model->items, iter->user_data);
+  if (G_UNLIKELY (idx < 0))
     return NULL;
 
-  return gtk_tree_path_new_from_indices (index, -1);
+  return gtk_tree_path_new_from_indices (idx, -1);
 }
 
 
@@ -743,11 +701,15 @@ exo_die_desktop_model_match_func (GtkEntryCompletion *completion,
   desktop_item = g_slist_nth_data (iter->user_data, 0);
 
   /* check if the name matches */
-  normalized = g_utf8_normalize (desktop_item->name, -1, G_NORMALIZE_ALL);
-  casefolded = g_utf8_casefold (normalized, -1);
-  matches = (strstr (casefolded, key) != NULL);
-  g_free (casefolded);
-  g_free (normalized);
+  if (G_LIKELY (desktop_item->name != NULL))
+    {
+      normalized = g_utf8_normalize (desktop_item->name, -1, G_NORMALIZE_ALL);
+      casefolded = g_utf8_casefold (normalized, -1);
+      if (G_LIKELY (casefolded != NULL && key != NULL))
+        matches = (strstr (casefolded, key) != NULL);
+      g_free (casefolded);
+      g_free (normalized);
+    }
 
   /* check if no hit yet */
   if (G_LIKELY (!matches && desktop_item->comment != NULL))
@@ -755,7 +717,8 @@ exo_die_desktop_model_match_func (GtkEntryCompletion *completion,
       /* also check the comment then */
       normalized = g_utf8_normalize (desktop_item->comment, -1, G_NORMALIZE_ALL);
       casefolded = g_utf8_casefold (normalized, -1);
-      matches = (strstr (casefolded, key) != NULL);
+      if (G_LIKELY (casefolded != NULL && key != NULL))
+        matches = (strstr (casefolded, key) != NULL);
       g_free (casefolded);
       g_free (normalized);
     }
