@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -12,9 +11,9 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,8 +43,6 @@ enum
 
 
 
-static void exo_helper_chooser_class_init   (ExoHelperChooserClass  *klass);
-static void exo_helper_chooser_init         (ExoHelperChooser       *chooser);
 static void exo_helper_chooser_finalize     (GObject                *object);
 static void exo_helper_chooser_get_property (GObject                *object,
                                              guint                   prop_id,
@@ -82,36 +79,7 @@ struct _ExoHelperChooser
 
 
 
-static GObjectClass *exo_helper_chooser_parent_class;
-
-
-
-GType
-exo_helper_chooser_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (ExoHelperChooserClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) exo_helper_chooser_class_init,
-        NULL,
-        NULL,
-        sizeof (ExoHelperChooser),
-        0,
-        (GInstanceInitFunc) exo_helper_chooser_init,
-        NULL,
-      };
-
-      type = g_type_register_static (GTK_TYPE_ALIGNMENT, I_("ExoHelperChooser"), &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoHelperChooser, exo_helper_chooser, GTK_TYPE_ALIGNMENT)
 
 
 
@@ -120,9 +88,6 @@ exo_helper_chooser_class_init (ExoHelperChooserClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_helper_chooser_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_helper_chooser_finalize;
   gobject_class->get_property = exo_helper_chooser_get_property;
@@ -175,7 +140,7 @@ exo_helper_chooser_init (ExoHelperChooser *chooser)
   chooser->database = exo_helper_database_get ();
 
   chooser->tooltips = gtk_tooltips_new ();
-  exo_gtk_object_ref_sink (GTK_OBJECT (chooser->tooltips));
+  g_object_ref_sink (G_OBJECT (chooser->tooltips));
 
   gtk_widget_push_composite_child ();
 
@@ -349,6 +314,7 @@ menu_activate (GtkWidget        *item,
   {
     N_("Failed to set default Web Browser"),
     N_("Failed to set default Mail Reader"),
+    N_("Failed to set default File Manager"),
     N_("Failed to set default Terminal Emulator"),
   };
 
@@ -534,6 +500,7 @@ menu_activate_other (GtkWidget        *item,
   {
     N_("Choose a custom Web Browser"),
     N_("Choose a custom Mail Reader"),
+    N_("Choose a custom File Manager"),
     N_("Choose a custom Terminal Emulator"),
   };
 
@@ -541,6 +508,7 @@ menu_activate_other (GtkWidget        *item,
   {
     N_("Specify the application you want to use\nas default Web Browser for Xfce:"),
     N_("Specify the application you want to use\nas default Mail Reader for Xfce:"),
+    N_("Specify the application you want to use\nas default File Manager for Xfce:"),
     N_("Specify the application you want to use\nas default Terminal Emulator for Xfce:"),
   };
 
@@ -556,7 +524,8 @@ menu_activate_other (GtkWidget        *item,
   GtkWidget   *button;
 
   /* sanity check the category values */
-  g_assert (EXO_HELPER_N_CATEGORIES == 3);
+  g_assert (EXO_HELPER_N_CATEGORIES == G_N_ELEMENTS (BROWSE_TITLES));
+  g_assert (EXO_HELPER_N_CATEGORIES == G_N_ELEMENTS (BROWSE_MESSAGES));
 
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (chooser));
 
@@ -589,7 +558,7 @@ menu_activate_other (GtkWidget        *item,
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
-  label = g_object_new (GTK_TYPE_LABEL, 
+  label = g_object_new (GTK_TYPE_LABEL,
                         "label", _(BROWSE_MESSAGES[chooser->category]),
                         "xalign", 0.0,
                         "yalign", 0.0,
@@ -724,7 +693,7 @@ exo_helper_chooser_pressed (ExoHelperChooser *chooser,
 
   /* allocate a new menu */
   menu = gtk_menu_new ();
-  exo_gtk_object_ref_sink (GTK_OBJECT (menu));
+  g_object_ref_sink (G_OBJECT (menu));
   gtk_menu_set_screen (GTK_MENU (menu), gtk_widget_get_screen (button));
 
   /* set Atk popup-window relation for the menu */
@@ -746,7 +715,7 @@ exo_helper_chooser_pressed (ExoHelperChooser *chooser,
     {
       /* determine the helper */
       helper = EXO_HELPER (lp->data);
-      
+
       /* add a menu item for the helper */
       item = gtk_image_menu_item_new_with_label (exo_helper_get_name (helper));
       g_object_set_data_full (G_OBJECT (item), I_("exo-helper"), helper, g_object_unref);
@@ -833,7 +802,7 @@ exo_helper_chooser_pressed (ExoHelperChooser *chooser,
 GtkWidget*
 exo_helper_chooser_new (ExoHelperCategory category)
 {
-  g_return_val_if_fail (category >= 0 && category < EXO_HELPER_N_CATEGORIES, NULL);
+  g_return_val_if_fail (category < EXO_HELPER_N_CATEGORIES, NULL);
   return g_object_new (EXO_TYPE_HELPER_CHOOSER, "category", category, NULL);
 }
 
@@ -869,7 +838,7 @@ exo_helper_chooser_set_category (ExoHelperChooser *chooser,
                                  ExoHelperCategory category)
 {
   g_return_if_fail (EXO_IS_HELPER_CHOOSER (chooser));
-  g_return_if_fail (category >= 0 && category < EXO_HELPER_N_CATEGORIES);
+  g_return_if_fail (category < EXO_HELPER_N_CATEGORIES);
 
   /* apply the new category */
   chooser->category = category;
