@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -12,9 +11,9 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,7 +48,6 @@
 
 
 
-static void       exo_helper_class_init (ExoHelperClass *klass);
 static void       exo_helper_finalize   (GObject        *object);
 static ExoHelper *exo_helper_new        (const gchar    *id,
                                          XfceRc         *rc);
@@ -77,36 +75,7 @@ struct _ExoHelper
 
 
 
-static GObjectClass *exo_helper_parent_class;
-
-
-
-GType
-exo_helper_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (ExoHelperClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) exo_helper_class_init,
-        NULL,
-        NULL,
-        sizeof (ExoHelper),
-        0,
-        NULL,
-        NULL,
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, I_("ExoHelper"), &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoHelper, exo_helper, G_TYPE_OBJECT)
 
 
 
@@ -115,15 +84,19 @@ exo_helper_class_init (ExoHelperClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_helper_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_helper_finalize;
 }
 
 
 
+static void
+exo_helper_init (ExoHelper *helpers)
+{
+}
+
+
+
 static void
 exo_helper_finalize (GObject *object)
 {
@@ -210,13 +183,13 @@ exo_helper_new (const gchar *id,
 
   /* determine the name of the helper */
   str = xfce_rc_read_entry (rc, "Name", NULL);
-  if (G_UNLIKELY (str == NULL || *str == '\0'))
+  if (G_UNLIKELY (exo_str_is_empty (str)))
     goto failed;
   helper->name = g_strdup (str);
 
   /* determine the icon of the helper */
   str = xfce_rc_read_entry_untranslated (rc, "Icon", NULL);
-  if (G_LIKELY (str != NULL && *str != '\0'))
+  if (G_LIKELY (!exo_str_is_empty (str)))
     helper->icon = g_strdup (str);
 
   /* determine the commands */
@@ -373,17 +346,18 @@ exo_helper_execute (ExoHelper   *helper,
                     const gchar *parameter,
                     GError     **error)
 {
-  GTimeVal previous;
-  GTimeVal current;
-  gboolean succeed = FALSE;
-  GError  *err = NULL;
-  gchar  **commands;
-  gchar  **argv;
-  gchar   *command;
-  guint    n;
-  gint     status;
-  gint     result;
-  gint     pid;
+  GTimeVal      previous;
+  GTimeVal      current;
+  gboolean      succeed = FALSE;
+  GError       *err = NULL;
+  gchar       **commands;
+  gchar       **argv;
+  gchar        *command;
+  guint         n;
+  gint          status;
+  gint          result;
+  gint          pid;
+  const gchar  *real_parameter = parameter;
 
   // FIXME: startup-notification
 
@@ -395,8 +369,12 @@ exo_helper_execute (ExoHelper   *helper,
   if (G_UNLIKELY (screen == NULL))
     screen = gdk_screen_get_default ();
 
+  /* strip the mailto part if needed */
+  if (real_parameter != NULL && g_str_has_prefix (real_parameter, "mailto:"))
+    real_parameter = parameter + 7;
+
   /* determine the command set to use */
-  commands = (parameter != NULL) ? helper->commands_with_parameter : helper->commands;
+  commands = !exo_str_is_empty (real_parameter) ? helper->commands_with_parameter : helper->commands;
 
   /* verify that we have atleast one command */
   if (G_UNLIKELY (*commands == NULL))
@@ -412,7 +390,7 @@ exo_helper_execute (ExoHelper   *helper,
       g_clear_error (&err);
 
       /* parse the command */
-      command = (parameter != NULL) ? exo_str_replace (commands[n], "%s", parameter) : g_strdup (commands[n]);
+      command = !exo_str_is_empty (real_parameter) ? exo_str_replace (commands[n], "%s", real_parameter) : g_strdup (commands[n]);
       succeed = g_shell_parse_argv (command, NULL, &argv, &err);
       g_free (command);
 
@@ -485,8 +463,6 @@ exo_helper_execute (ExoHelper   *helper,
 
 
 
-static void       exo_helper_database_class_init  (ExoHelperDatabaseClass *klass);
-static void       exo_helper_database_init        (ExoHelperDatabase      *database);
 static void       exo_helper_database_finalize    (GObject                *object);
 static ExoHelper *exo_helper_database_lookup      (ExoHelperDatabase      *database,
                                                    ExoHelperCategory       category,
@@ -507,36 +483,7 @@ struct _ExoHelperDatabase
 
 
 
-static GObjectClass *exo_helper_database_parent_class;
-
-
-
-GType
-exo_helper_database_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (ExoHelperDatabaseClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) exo_helper_database_class_init,
-        NULL,
-        NULL,
-        sizeof (ExoHelperDatabase),
-        0,
-        (GInstanceInitFunc) exo_helper_database_init,
-        NULL,
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, I_("ExoHelperDatabase"), &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoHelperDatabase, exo_helper_database, G_TYPE_OBJECT)
 
 
 
@@ -545,9 +492,6 @@ exo_helper_database_class_init (ExoHelperDatabaseClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_helper_database_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_helper_database_finalize;
 }
@@ -725,8 +669,12 @@ exo_helper_database_set_default (ExoHelperDatabase *database,
                                  ExoHelper         *helper,
                                  GError           **error)
 {
-  XfceRc *rc;
-  gchar  *key;
+  XfceRc       *rc, *desktop_file;
+  gchar        *key;
+  const gchar  *filename;
+  gchar       **mimetypes;
+  guint         i;
+  gchar        *path;
 
   g_return_val_if_fail (category < EXO_HELPER_N_CATEGORIES, FALSE);
   g_return_val_if_fail (EXO_IS_HELPER_DATABASE (database), FALSE);
@@ -737,7 +685,7 @@ exo_helper_database_set_default (ExoHelperDatabase *database,
   rc = xfce_rc_config_open (XFCE_RESOURCE_CONFIG, "xfce4/helpers.rc", FALSE);
   if (G_UNLIKELY (rc == NULL))
     {
-      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_IO, _("Failed to open helpers.rc for writing"));
+      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_IO, _("Failed to open %s for writing"), "helpers.rc");
       return FALSE;
     }
 
@@ -747,6 +695,58 @@ exo_helper_database_set_default (ExoHelperDatabase *database,
   xfce_rc_close (rc);
   g_free (key);
 
+  /* get the desktop filename */
+  switch (category)
+    {
+      case EXO_HELPER_WEBBROWSER:
+        filename = "exo-web-browser.desktop";
+        break;
+
+      case EXO_HELPER_MAILREADER:
+        filename = "exo-mail-reader.desktop";
+        break;
+
+      case EXO_HELPER_FILEMANAGER:
+        filename = "exo-file-manager.desktop";
+        break;
+
+      default:
+        /* no mimetype support for terminals */
+        return TRUE;
+    }
+
+  /* open the mimeapp.list file to set the default handler of the mime type */
+  rc = xfce_rc_config_open (XFCE_RESOURCE_DATA, "applications/mimeapps.list", FALSE);
+  if (G_UNLIKELY (rc == NULL))
+    {
+      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_IO, _("Failed to open %s for writing"), "mimeapps.list");
+      return FALSE;
+    }
+
+  /* open the exo desktop file to read the mimetypes the file supports */
+  path = g_build_filename ("applications", filename, NULL);
+  desktop_file = xfce_rc_config_open (XFCE_RESOURCE_DATA, path, TRUE);
+  g_free (path);
+
+  if (G_UNLIKELY (desktop_file != NULL))
+    {
+      xfce_rc_set_group (desktop_file, "Desktop Entry");
+      mimetypes = xfce_rc_read_list_entry (desktop_file, "X-XFCE-MimeType", ";");
+      if (mimetypes != NULL)
+        {
+          xfce_rc_set_group (rc, "Added Associations");
+
+          for (i = 0; mimetypes[i] != NULL; i++)
+            if (!exo_str_is_empty (mimetypes[i]))
+              xfce_rc_write_entry (rc, mimetypes[i], filename);
+          g_strfreev (mimetypes);
+        }
+
+      xfce_rc_close (desktop_file);
+    }
+
+  xfce_rc_close (rc);
+
   return TRUE;
 }
 
@@ -873,14 +873,14 @@ exo_helper_database_set_custom (ExoHelperDatabase *database,
   XfceRc *rc;
   gchar **argv;
   gchar  *category_string;
-  gchar  *basename;
+  gchar  *name;
   gchar  *cmdline;
   gchar  *file;
   gchar   spec[256];
 
   g_return_if_fail (EXO_IS_HELPER_DATABASE (database));
   g_return_if_fail (category < EXO_HELPER_N_CATEGORIES);
-  g_return_if_fail (command != NULL && *command != '\0');
+  g_return_if_fail (!exo_str_is_empty (command));
 
   /* determine the spec for the custom helper */
   category_string = exo_helper_category_to_string (category);
@@ -910,10 +910,10 @@ exo_helper_database_set_custom (ExoHelperDatabase *database,
       if (g_shell_parse_argv (cmdline, NULL, &argv, NULL))
         {
           /* use the basename for Name and Icon */
-          basename = g_path_get_basename (*argv);
-          xfce_rc_write_entry (rc, "Icon", basename);
-          xfce_rc_write_entry (rc, "Name", basename);
-          g_free (basename);
+          name = g_path_get_basename (*argv);
+          xfce_rc_write_entry (rc, "Icon", name);
+          xfce_rc_write_entry (rc, "Name", name);
+          g_free (name);
 
           /* use only the binary for the Commands */
           xfce_rc_write_entry (rc, "X-XFCE-Commands", *argv);
