@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -12,10 +11,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,10 +41,10 @@
 #include <exo/exo-thumbnail.h>
 #include <exo/exo-utils.h>
 #include <exo/exo-alias.h>
+#include <exo/exo-string.h>
 
 
 
-static void exo_thumbnail_preview_init      (ExoThumbnailPreview *thumbnail_preview);
 static void exo_thumbnail_preview_style_set (GtkWidget           *ebox,
                                              GtkStyle            *previous_style,
                                              ExoThumbnailPreview *thumbnail_preview);
@@ -67,22 +66,13 @@ struct _ExoThumbnailPreview
 
 
 
-GType
-_exo_thumbnail_preview_get_type (void)
+G_DEFINE_TYPE (ExoThumbnailPreview, exo_thumbnail_preview, GTK_TYPE_FRAME)
+
+
+
+static void
+exo_thumbnail_preview_class_init (ExoThumbnailPreviewClass *klass)
 {
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      type = _exo_g_type_register_simple (GTK_TYPE_FRAME,
-                                          "ExoThumbnailPreview",
-                                          sizeof (ExoThumbnailPreviewClass),
-                                          NULL,
-                                          sizeof (ExoThumbnailPreview),
-                                          exo_thumbnail_preview_init);
-    }
-
-  return type;
 }
 
 
@@ -174,7 +164,7 @@ exo_thumbnail_preview_style_set (GtkWidget           *ebox,
  *
  * Allocates a new #ExoThumbnailPreview instance.
  *
- * Return value: the newly allocated #ExoThumbnailPreview.
+ * Returns: the newly allocated #ExoThumbnailPreview.
  **/
 GtkWidget*
 _exo_thumbnail_preview_new (void)
@@ -266,7 +256,7 @@ _exo_thumbnail_preview_set_uri (ExoThumbnailPreview *thumbnail_preview,
   GdkPixbuf  *thumbnail;
   gchar      *icon_name = NULL;
   gchar      *size_name = NULL;
-  gchar      *basename;
+  gchar      *displayname;
   gchar      *filename;
   gchar      *slash;
 
@@ -332,16 +322,16 @@ _exo_thumbnail_preview_set_uri (ExoThumbnailPreview *thumbnail_preview,
             }
 
           /* determine the basename from the filename */
-          basename = g_filename_display_basename (filename);
+          displayname = g_filename_display_basename (filename);
         }
       else
         {
           /* determine the basename from the URI */
           slash = strrchr (uri, '/');
-          if (G_LIKELY (slash != NULL && slash[1] != '\0'))
-            basename = g_filename_display_name (slash + 1);
+          if (G_LIKELY (!exo_str_is_empty (slash)))
+            displayname = g_filename_display_name (slash + 1);
           else
-            basename = g_filename_display_name (uri);
+            displayname = g_filename_display_name (uri);
         }
 
       /* check if we have an icon-name */
@@ -378,10 +368,10 @@ _exo_thumbnail_preview_set_uri (ExoThumbnailPreview *thumbnail_preview,
         }
 
       /* setup the name label */
-      gtk_label_set_text (GTK_LABEL (thumbnail_preview->name_label), basename);
+      gtk_label_set_text (GTK_LABEL (thumbnail_preview->name_label), displayname);
 
       /* cleanup */
-      g_free (basename);
+      g_free (displayname);
       g_free (filename);
     }
 
