@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2004-2006 os-cillation e.K.
  * Copyright (c) 2003      Marco Pesenti Gritti
@@ -15,10 +14,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,9 +40,25 @@
 #include <exo/exo-toolbars-private.h>
 #include <exo/exo-alias.h>
 
+/**
+ * SECTION: exo-toolbars-editor
+ * @title: ExoToolbarsEditor
+ * @short_description: Widget to edit toolbars
+ * @include: exo/exo.h
+ * @see_also: #ExoToolbarsEditorDialog
+ *
+ * #ExoToolbarsEditor is a widget that allows the user to edit toolbars
+ * used within your application by simply dragging and dropping toolbar
+ * items between the editor widget and the toolbar widgets.
+ *
+ * Most applications should simply use the #ExoToolbarsEditorDialog
+ * class, which includes an #ExoToolbarsEditor as main widget.
+ **/
 
 
-#define EXO_TOOLBARS_EDITOR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EXO_TYPE_TOOLBARS_EDITOR, ExoToolbarsEditorPrivate))
+
+#define EXO_TOOLBARS_EDITOR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
+    EXO_TYPE_TOOLBARS_EDITOR, ExoToolbarsEditorPrivate))
 
 
 
@@ -56,8 +71,6 @@ enum
 
 
 
-static void       exo_toolbars_editor_class_init          (ExoToolbarsEditorClass *klass);
-static void       exo_toolbars_editor_init                (ExoToolbarsEditor      *editor);
 static void       exo_toolbars_editor_finalize            (GObject                *object);
 static void       exo_toolbars_editor_get_property        (GObject                *object,
                                                            guint                   prop_id,
@@ -71,7 +84,7 @@ static void       exo_toolbars_editor_drag_data_get       (GtkWidget
                                                            GdkDragContext         *context,
                                                            GtkSelectionData       *selection_data,
                                                            guint                   info,
-                                                           guint32                 time,
+                                                           guint32                 drag_time,
                                                            ExoToolbarsEditor      *editor);
 static GtkWidget *exo_toolbars_editor_create_item         (ExoToolbarsEditor      *editor,
                                                            GtkWidget              *image,
@@ -102,27 +115,7 @@ static const GtkTargetEntry targets[] =
 
 
 
-static GObjectClass *exo_toolbars_editor_parent_class;
-
-
-
-GType
-exo_toolbars_editor_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      type = _exo_g_type_register_simple (GTK_TYPE_VBOX,
-                                          "ExoToolbarsEditor",
-                                          sizeof (ExoToolbarsEditorClass),
-                                          exo_toolbars_editor_class_init,
-                                          sizeof (ExoToolbarsEditor),
-                                          exo_toolbars_editor_init);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoToolbarsEditor, exo_toolbars_editor, GTK_TYPE_VBOX)
 
 
 
@@ -132,8 +125,6 @@ exo_toolbars_editor_class_init (ExoToolbarsEditorClass *klass)
   GObjectClass *gobject_class;
 
   g_type_class_add_private (klass, sizeof (ExoToolbarsEditorPrivate));
-  
-  exo_toolbars_editor_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_toolbars_editor_finalize;
@@ -311,7 +302,7 @@ exo_toolbars_editor_drag_data_get (GtkWidget          *item,
                                    GdkDragContext     *context,
                                    GtkSelectionData   *selection_data,
                                    guint               info,
-                                   guint32             time,
+                                   guint32             drag_time,
                                    ExoToolbarsEditor  *editor)
 {
   const gchar *target;
@@ -393,6 +384,8 @@ exo_toolbars_editor_create_item (ExoToolbarsEditor  *editor,
 
   text_no_mnemonic = exo_str_elide_underscores (text);
   label = gtk_label_new (text_no_mnemonic);
+  gtk_widget_set_tooltip_text (ebox, text_no_mnemonic);
+  gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
   g_free (text_no_mnemonic);
   gtk_widget_show (label);
@@ -567,13 +560,13 @@ exo_toolbars_editor_update (ExoToolbarsEditor *editor)
  * You should probably use exo_toolbars_editor_new_with_model()
  * instead.
  *
- * Return value: A new #ExoToolbarsEditor.
+ * Returns: A new #ExoToolbarsEditor.
  **/
 GtkWidget*
 exo_toolbars_editor_new (GtkUIManager *ui_manager)
 {
   g_return_val_if_fail (GTK_IS_UI_MANAGER (ui_manager), NULL);
-  
+
   return g_object_new (EXO_TYPE_TOOLBARS_EDITOR,
                        "ui-manager", ui_manager,
                        NULL);
@@ -592,7 +585,7 @@ exo_toolbars_editor_new (GtkUIManager *ui_manager)
  * #ExoToolbarsModel here or the function will
  * fail.
  *
- * Return value: A new #ExoToolbarsEditor.
+ * Returns: A new #ExoToolbarsEditor.
  **/
 GtkWidget*
 exo_toolbars_editor_new_with_model (GtkUIManager     *ui_manager,
@@ -617,7 +610,7 @@ exo_toolbars_editor_new_with_model (GtkUIManager     *ui_manager,
  * with @editor or %NULL if no #ExoToolbarsModel is
  * currently associated with @editor.
  *
- * Return value: An #ExoToolbarsModel or %NULL.
+ * Returns: An #ExoToolbarsModel or %NULL.
  **/
 ExoToolbarsModel*
 exo_toolbars_editor_get_model (ExoToolbarsEditor *editor)
@@ -690,7 +683,7 @@ exo_toolbars_editor_set_model (ExoToolbarsEditor *editor,
  * @editor or %NULL if no user interface
  * manager is associated with @editor currently.
  *
- * Return value: A #GtkUIManager or %NULL.
+ * Returns: A #GtkUIManager or %NULL.
  **/
 GtkUIManager*
 exo_toolbars_editor_get_ui_manager (ExoToolbarsEditor *editor)
